# Differential Serve

Adds the ability to [differentially serve](https://css-tricks.com/differential-serving/)
JavaScript on the basis of whether the current browser supports ES6 modules or
not. This allows users to pay less of a penalty for when a site needs to support
older browsers.

There is some extra wrangling to support edge cases where a browser may not
respect the `nomodule` attribute and would then potentially execute more scripts
than desired.

## Usage

In `extension.libraries.yml`:

```yml
scripts:
  js:
    modern.js: { differential_serve: 'modern' } # ES6 only.
    legacy.js: { differential_serve: 'legacy' } # ES5 only.
  dependencies:
    - differential_serve/legacy_loader # Required to load ES5 legacy scripts.
```

## Gotchas

Initial attached legacy scripts may not get their Drupal behavior `attach()`
methods called on the initial page load, due to the async nature of their
loading.
